Index: trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/evaluation/EvaluateResultXML.java
===================================================================
--- trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/evaluation/EvaluateResultXML.java	(revision 1170)
+++ trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/evaluation/EvaluateResultXML.java	(revision 1247)
@@ -173,14 +173,14 @@
 //		System.out.println(f2.list()[0]);
 		
-		String projectPath = "C:\\Projects\\ModelicaML\\runtime-New_configuration\\modelicaml.example.potableWaterSystem_v26\\test-gen\\test-session_20110924175101\\tmp\\ModelicaMLModel.GenSimModels_for__SPWS_Environment_1.SiM_for__ts2__Fill_tank_res.xml";
+		String pathToResultXML = "C:/Projects/ModelicaML/runtime-New_configuration/modelicaml.example.potableWaterSystem_v30/verification-gen/verification-session_20120124110026\\ModelicaMLModel.GenVeMs_for__SPWS_Environment_1.VeM_for__s1_Fill_and_Drain_Tank_res.xml";
 		
 //		SimulationResult sr = SimulationResult_XML_reader.readFromXML("_reqTestVerdict.allRequirementsEvaluated", projectPath);
-		String propertyName = "_reqTestVerdict.allRequirementsEvaluated";
+		String propertyName = "_reqVerificationVerdict.allRequirementsEvaluated";
 		
-		System.out.println(checkAtLeastOneTimeTrue(propertyName, new File(projectPath)));
-		System.out.println(checkAtLeastOneTimeFalse(propertyName, new File(projectPath)));
-		System.out.println(checkAlwaysTrue(propertyName, new File(projectPath)));
-		System.out.println(checkAlwaysFalse(propertyName, new File(projectPath)));
-		System.out.println(checkChangedItsValue(propertyName, new File(projectPath)));
+		System.out.println(checkAtLeastOneTimeTrue(propertyName, new File(pathToResultXML)));
+		System.out.println(checkAtLeastOneTimeFalse(propertyName, new File(pathToResultXML)));
+		System.out.println(checkAlwaysTrue(propertyName, new File(pathToResultXML)));
+		System.out.println(checkAlwaysFalse(propertyName, new File(pathToResultXML)));
+		System.out.println(checkChangedItsValue(propertyName, new File(pathToResultXML)));
 	}
 }
Index: trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/execution/ExecuteSimulation.java
===================================================================
--- trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/execution/ExecuteSimulation.java	(revision 1170)
+++ trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/execution/ExecuteSimulation.java	(revision 1247)
@@ -3,5 +3,4 @@
 
 import org.eclipse.core.runtime.IProgressMonitor;
-import org.eclipse.core.runtime.Status;
 import org.openmodelica.modelicaml.simulation.filehandling.cp;
 import org.openmodelica.modelicaml.simulation.omc.OpenModelicaCompilerCommunication;
@@ -43,5 +42,5 @@
 		
 		
-		check_simulate(monitor, omcc, testSessionObj, omcReturnString);
+		check_and_simulate(monitor, omcc, testSessionObj, omcReturnString);
 		
 		omcc.quit();
@@ -79,9 +78,9 @@
 	}
 
-	private static String check_simulate(IProgressMonitor monitor, OpenModelicaCompilerCommunication omcc, TestSession testSessionObj, String omcReturnString) {
+	private static String check_and_simulate(IProgressMonitor monitor, OpenModelicaCompilerCommunication omcc, TestSession testSessionObj, String omcReturnString) {
 
 		//Check Model
 		for(TestModel model : testSessionObj.testModels){
-			monitor.subTask("Simulating: " + model.qualifiedName);
+//			monitor.subTask("Simulating: " + model.qualifiedName); [20120127 TODO uncomment monitor]
 			omcReturnString =  omcc.checkModel(model.qualifiedName);
 			
@@ -109,12 +108,12 @@
 	 */
 	public static void main(String[] args) {
-		String sessionFolderPath = "C:\\Projects\\ModelicaML\\runtime-New_configuration\\modelicaml.example.potableWaterSystem_v26\\test-gen\\test-session_20110927133331\\";
+		String pathToSession = "C:/Projects/ModelicaML/runtime-New_configuration/modelicaml.example.potableWaterSystem_v30/verification-gen/verification-session_20120124110026\\";
 		
-		TestSession testSessionObj = TestSessionXML_Reader.readFromXML(sessionFolderPath + "test_session.xml");
+		TestSession testSessionObj = TestSessionXML_Reader.readFromXML(pathToSession + "verification_session.xml");
 		String omcTempWorkingFolder = System.getenv().get("OPENMODELICAHOME") + "/tmp"; 
-		File sessionFolder = new File(sessionFolderPath);
-		File tempSimulationFolder = new File(sessionFolderPath + "tmp");
-		tempSimulationFolder.mkdir();
-		tempSimulationFolder.canWrite();
+		File sessionFolder = new File(pathToSession);
+//		File tempSimulationFolder = new File(pathToSession + "tmp");
+//		tempSimulationFolder.mkdir();
+//		tempSimulationFolder.canWrite();
 		String omcMessage =	executeAllModels(null, sessionFolder, omcTempWorkingFolder, testSessionObj);
 		if(omcMessage.isEmpty()){
@@ -125,7 +124,7 @@
 		
 		for(TestModel model : testSessionObj.testModels){
-			cp.copyFile(omcTempWorkingFolder + "/" + model.qualifiedName + ".exe", tempSimulationFolder + "/" + model.qualifiedName + ".exe");
-			cp.copyFile(omcTempWorkingFolder + "/" + model.qualifiedName + "_init.xml", tempSimulationFolder + "/" + model.qualifiedName + "_init.xml");
-			cp.copyFile(omcTempWorkingFolder + "/" + model.qualifiedName + "_res.plt", tempSimulationFolder + "/" + model.qualifiedName + "_res.plt");
+			cp.copyFile(omcTempWorkingFolder + "/" + model.qualifiedName + ".exe", pathToSession + "/" + model.qualifiedName + ".exe");
+			cp.copyFile(omcTempWorkingFolder + "/" + model.qualifiedName + "_init.xml", pathToSession + "/" + model.qualifiedName + "_init.xml");
+			cp.copyFile(omcTempWorkingFolder + "/" + model.qualifiedName + "_res.plt", pathToSession + "/" + model.qualifiedName + "_res.plt");
 		}
 	}
Index: trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/plot/SimulationCenter_NonInteractive.java
===================================================================
--- trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/plot/SimulationCenter_NonInteractive.java	(revision 1247)
+++ trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/plot/SimulationCenter_NonInteractive.java	(revision 1247)
@@ -0,0 +1,150 @@
+/*
+ * This file is part of OpenModelica.
+ *
+ * Copyright (c) 1998-CurrentYear, Open Source Modelica Consortium (OSMC),
+ * c/o Linköpings universitet, Department of Computer and Information Science,
+ * SE-58183 Linköping, Sweden.
+ *
+ * All rights reserved.
+ *
+ * THIS PROGRAM IS PROVIDED UNDER THE TERMS OF GPL VERSION 3 LICENSE OR 
+ * THIS OSMC PUBLIC LICENSE (OSMC-PL). 
+ * ANY USE, REPRODUCTION OR DISTRIBUTION OF THIS PROGRAM CONSTITUTES RECIPIENT'S ACCEPTANCE
+ * OF THE OSMC PUBLIC LICENSE OR THE GPL VERSION 3, ACCORDING TO RECIPIENTS CHOICE. 
+ *
+ * The OpenModelica software and the Open Source Modelica
+ * Consortium (OSMC) Public License (OSMC-PL) are obtained
+ * from OSMC, either from the above address,
+ * from the URLs: http://www.ida.liu.se/projects/OpenModelica or  
+ * http://www.openmodelica.org, and in the OpenModelica distribution. 
+ * GNU version 3 is obtained from: http://www.gnu.org/copyleft/gpl.html.
+ *
+ * This program is distributed WITHOUT ANY WARRANTY; without
+ * even the implied warranty of  MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE, EXCEPT AS EXPRESSLY SET FORTH
+ * IN THE BY RECIPIENT SELECTED SUBSIDIARY LICENSE CONDITIONS OF OSMC-PL.
+ *
+ * See the full OSMC Public License conditions for more details.
+ *
+ * Main author: Wladimir Schamai, EADS Innovation Works / Linköping University, 2009-now
+ *
+ * Contributors: 
+ *   Uwe Pohlmann, University of Paderborn 2009-2010, contribution to the Modelica code generation for state machine behavior, contribution to Papyrus GUI adoptations
+ *   Parham Vasaiely, EADS Innovation Works / Hamburg University of Applied Sciences 2009-2011, implementation of simulation plugins
+ */
+package org.openmodelica.modelicaml.simulation.plot;
+
+import java.util.Observer;
+
+import org.openmodelica.simulation.core.models.simulation.SimulationProject;
+import org.openmodelica.simulation.core.models.simulation.SimulationSessionConfiguration;
+import org.openmodelica.simulation.core.simulationdata.SimulationResultManager_NonInteractive;
+// TODO: Auto-generated Javadoc
+/**
+ * The Simulation Center is the central management unit to run a non interactive simulation. 
+ * It contains all information and data to simulate a system using
+ * the OpenModelica Compiler (OMC). 
+ * @author EADS Innovation Works, Parham Vasaiely, Parham.Vasaiely@eads.com
+ *
+ */
+public class SimulationCenter_NonInteractive{
+	
+    /** Path to the _res.xml file which is the result of a test simulation */
+	private String xmlResultFile;
+	
+	/**
+	 * All properties which should display on plot
+	 * TODO [20101111] The properties won't be filtered using a plot check button... this will be done in a future version
+	 */
+	//private List<ModelicaProperty> plotProperties;  //  @jve:decl-index=0:
+	
+	/**
+	 * Result manager for a non interactive simulation
+	 */
+	private SimulationResultManager_NonInteractive simulationResultManager;
+	
+	/**
+	 * Instantiates a new simulation center_ non interactive.
+	 */
+	public SimulationCenter_NonInteractive(){
+			simulationResultManager = new SimulationResultManager_NonInteractive();
+	}
+	
+	/**
+	 * Instantiates a new simulation center_ non interactive.
+	 */
+	public SimulationCenter_NonInteractive(String xmlResultFile){
+		this.xmlResultFile = xmlResultFile;
+		this.simulationResultManager = new SimulationResultManager_NonInteractive();
+	}
+	
+	/*
+	 *************************************************************************
+	 * Getter and Setter for the fields...
+	 *************************************************************************
+	 */
+	
+	/**
+	 * Gets the simulation result manager.
+	 *
+	 * @return a SimulationResultManager
+	 * @see #simulationResultManager
+	 */
+	public SimulationResultManager_NonInteractive getSimulationResultManager() {
+		return simulationResultManager;
+	}
+
+	/*
+	 *************************************************************************
+	 * Thread and Resource Organization, Management: Start, Stop, ClearAll...
+	 *************************************************************************
+	 */
+	
+	/**
+	 * After the executing of the simulation runtime a results file "_res.plt" will be created by a simulation runtime
+	 * this file must be evaluated and a corresponding XML file will be generated. 
+	 * @throws Exception while creating the XML result file
+	 */
+//	public void evaluatingResults() throws Exception{
+//		
+//		simulationResultManager.setResults(Result_TXT_reader.readResult(resultFilePath + "/" + resultFileName));
+//		
+//		//TODO [20101115] results XML will not be used to check performance
+////		Result_TXT_reader.readResult(resultFilePath + "/" + resultFileName);
+//		
+//		SimulationResult_XML_generator.createXML("", "", resultFilePath + "/" + resultFileName, resultFilePath + "/SimulationSessionConfigurations/" + selectedSimulationSessionConfiguration.getConfigurationName());
+//	}
+
+	/**
+	 * General method to stop all threads and clear resources.
+	 */
+	public void stopAll(){
+    	deleteAllObservers();
+    }
+	
+	/*
+	 *************************************************************************
+	 * Management of Views using the observer pattern... addObserver, deleteObserver...
+	 *************************************************************************
+	 */
+	
+	/**
+	 * Deletes all existing observers from simulationResultManager and this.
+	 */
+	private void deleteAllObservers(){
+		simulationResultManager.deleteObservers();
+	}
+	
+	/**
+	 * Adds a new view, plot to the non interactive simulation center
+	 * This plot will be notified on selected or unselected properties.
+	 *
+	 * @param newOberver New view/plot as an observer
+	 */
+	public void addPlot(Observer newOberver){
+		if(newOberver != null){
+			simulationResultManager.addObserver(newOberver);
+		}
+//		newOberver.update(simulationResultManager, "");	
+	}
+}
Index: trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/testexecution/actions/PlotTestResultsAction.java
===================================================================
--- trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/testexecution/actions/PlotTestResultsAction.java	(revision 1170)
+++ trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/testexecution/actions/PlotTestResultsAction.java	(revision 1247)
@@ -28,4 +28,6 @@
 		if (this.xmlFilePath != null) {
 			// TODO: open a new Dialog with the plotting facilities
+			// TODO [20111209] use same as DialogMessageWithHTMLBrowser
+			// new Shell OpenModelica-1.8.0-revision-10584.exe
 		}
 	}
Index: trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/testexecution/actions/UpdateTestExecutionReportDataAction.java
===================================================================
--- trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/testexecution/actions/UpdateTestExecutionReportDataAction.java	(revision 1170)
+++ trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/testexecution/actions/UpdateTestExecutionReportDataAction.java	(revision 1247)
@@ -8,4 +8,5 @@
 import org.eclipse.ui.IWorkbenchWindowActionDelegate;
 import org.eclipse.ui.PlatformUI;
+import org.openmodelica.modelicaml.simulation.evaluation.ParseJavaScript;
 
 public class UpdateTestExecutionReportDataAction implements
@@ -33,5 +34,5 @@
 			// TODO find the report_data.js_template in the folder "/includes/", 
 			// replace all place holders and save(overwrite) the report_data.js 
-			
+			ParseJavaScript.parseJSTemp_generateJSFile(sessionFolderPath);	
 		}
 	}
Index: trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/xml/SimulationResult_XML_generator.java
===================================================================
--- trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/xml/SimulationResult_XML_generator.java	(revision 1170)
+++ trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/xml/SimulationResult_XML_generator.java	(revision 1247)
@@ -130,6 +130,13 @@
 	public static void main(String[] args) {
 
+		String pathToProj = "C:/Projects/ModelicaML/runtime-New_configuration/modelicaml.example.potableWaterSystem_v30/verification-gen/verification-session_20120124110026\\";
+		String model1 = "ModelicaMLModel.GenVeMs_for__SPWS_Environment_1.VeM_for__s1_Fill_and_Drain_Tank_res.plt";
+		String model2 = "ModelicaMLModel.GenVeMs_for__SPWS_Environment_1.VeM_for__s2_Fill_tank_res.plt";
+		String model3 = "ModelicaMLModel.GenVeMs_for__SPWS_Environment_1.VeM_for__s3_Drain_tank_res.plt";
+		
 		try {
-				createXML("C:\\Projects\\ModelicaML\\runtime-New_configuration\\modelicaml.example.potableWaterSystem_v26\\test-gen\\test-session_20110924175101\\tmp\\ModelicaMLModel.GenSimModels_for__SPWS_Environment_1.SiM_for__ts2__Fill_tank_res.plt", "C:\\");
+			createXML(pathToProj + model1, pathToProj + "ModelicaMLModel.GenVeMs_for__SPWS_Environment_1.VeM_for__s1_Fill_and_Drain_Tank_res.xml");
+			createXML(pathToProj + model2, pathToProj + "ModelicaMLModel.GenVeMs_for__SPWS_Environment_1.VeM_for__s2_Fill_tank_res.xml");
+			createXML(pathToProj + model3, pathToProj + "ModelicaMLModel.GenVeMs_for__SPWS_Environment_1.VeM_for__s3_Drain_tank_res.xml");
 		} catch (Exception e) {
 			e.printStackTrace();
Index: trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/xml/TestSession.java
===================================================================
--- trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/xml/TestSession.java	(revision 1170)
+++ trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/xml/TestSession.java	(revision 1247)
@@ -3,4 +3,10 @@
 import java.util.ArrayList;
 
+/**
+ * 
+ * @author parham.vasaiely
+ *
+ * this class represents the test session containing a set of single test (verification) models. 
+ */
 public class TestSession {
 
@@ -13,4 +19,9 @@
 	}
 	
+	/**
+	 * Internal class test model. A test model contains all parameters to configure a simulation
+	 * @author parham.vasaiely
+	 *
+	 */
 	public static class TestModel{
 		public String qualifiedName;
Index: trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/xml/TestSessionXML_Reader.java
===================================================================
--- trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/xml/TestSessionXML_Reader.java	(revision 1170)
+++ trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/xml/TestSessionXML_Reader.java	(revision 1247)
@@ -20,9 +20,9 @@
 
 	/**
-	 * Reads a XML file, creates a ModelicaModel object and initializes it.
-	 * The XML file can be a "ModelInit.xml" or a "ModelConfig.xml"
+	 * Reads a XML file, creates a TestSession object and initializes it.
+	 * The XML file can be a "test_session.txt" or a "verification_session.txt"
 	 *
 	 * @param xml_file the xml_file
-	 * @return complete initialized ModelicaModel object
+	 * @return complete initialized TestSession object
 	 */
 	public static TestSession readFromXML(File xml_file) {
@@ -32,9 +32,9 @@
 	
 	/**
-	 * Reads a XML file, creates a ModelicaModel object and initializes it.
-	 * The XML file can be a "ModelInit.xml" or a "ModelConfig.xml"
+	 * Reads a XML file, creates a TestSession object and initializes it.
+	 * The XML file can be a "test_session.txt" or a "verification_session.txt"
 	 *
 	 * @param xml_file_path the xml_file_path
-	 * @return complete initialized ModelicaModel object
+	 * @return complete initialized TestSession object
 	 */
 	public static TestSession readFromXML(String xml_file_path) {
@@ -43,5 +43,5 @@
 	
 	/**
-	 * Creates the project.
+	 * Creates the TestSession.
 	 *
 	 * @param xmlFile the xml file
@@ -118,7 +118,10 @@
 	public static void main(String[] args) {
 		
-		String projectPath = "C:\\Projects\\ModelicaML\\modelicaml.example.potableWaterSystem_v26\\test-gen\\test-session_20110913192709\\test_session.xml";
+		String pathToSession = "C:/Projects/ModelicaML/runtime-New_configuration/modelicaml.example.potableWaterSystem_v30/verification-gen/verification-session_20120124110026/";
 		
-		TestSession ts = readFromXML(projectPath);
+		String testSessionObj = (pathToSession + "verification_session.xml");
+		
+		
+		TestSession ts = readFromXML(testSessionObj);
 		System.out.println(ts.packageFileRelativePath);
 		for(TestModel tempModel : ts.testModels){
@@ -126,4 +129,3 @@
 		}
 	}
-
 }

Index: trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/evaluation/ParseJavaScript.java
===================================================================
--- trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/evaluation/ParseJavaScript.java	(revision 1170)
+++ trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/evaluation/ParseJavaScript.java	(revision 1247)
@@ -16,5 +16,5 @@
 	 */
 	public static void main(String[] args) {
-		String pathToSession = "C:/Projects/ModelicaML/runtime-New_configuration/modelicaml.example.potableWaterSystem_v26/test-gen/test-session_20111021101526";
+		String pathToSession = "C:/Projects/ModelicaML/runtime-New_configuration/modelicaml.example.potableWaterSystem_v30/verification-gen/verification-session_20120124110026\\";
 		//String result_xml_file = "C:\\Projects\\ModelicaML\\runtime-New_configuration\\modelicaml.example.potableWaterSystem_v26\\test-gen\\test-session_20110927133331\\tmp\\ModelicaMLModel.GenSimModels_for__SPWS_Environment_6.SiM_for__ts2__Fill_tank_res.xml";
 		
@@ -22,9 +22,8 @@
 	}
 	
 	/**
 	 * Parses the JavaScript template file to generate a new JavaScript file including the evaluated results
 	 * @param result_xml_file result file including properties and results to be evaluated
 	 * @param pathToJSFiles path to the report-gen\includes folder
 	 */
 	public static void parseJSTemp_generateJSFile(String pathToSession){
 		/** The raf. */
@@ -85,4 +84,12 @@
 	}
 
+	/**
+	 * One iteration block covers the evaluation of one single simulation model and it's result file. In the JavaScript file it starts with {$START} and ends with {$END}
+	 * @param fw is the report_data.js
+	 * @param raf is the "report_data.js_template"
+	 * @param result_xml_file Result XML file which needs to be evaluated
+	 * @return a String containing the last line of an iteration "{$END}" or ERROR if the iteration block is not marked by "{$END}"
+	 * @throws IOException
+	 */
 	private static String startIteration(Writer fw, RandomAccessFile raf, String result_xml_file) throws IOException{
 		boolean hasDataSet = true;
@@ -107,7 +114,13 @@
 			}
 		}
-		return "ERROR"; // this line should never been reached since the end of the file is marked by {$END}
+		return "ERROR"; // this line should never been reached since the end of an iteration (start-end) should marked by {$END}
 	}
 	
+	/**
+	 * This methods parses an line from the iteration block which needs to be evaluated!
+	 * @param line Line in an iteration block which needs to be evaluated.
+	 * @param result_xml_file Result XML file which needs to be evaluated.
+	 * @return String which contains the full evaluated line.
+	 */
 	private static String startEvaluation(String line, String result_xml_file) {
 		String evaluatedLine;
@@ -22,9 +22,8 @@
 	}
 	
-	/**
-	 * Parses the JavaScript template file to generate a new JavaScript file including the evaluated results
-	 * @param result_xml_file result file including properties and results to be evaluated
-	 * @param pathToJSFiles path to the report-gen\includes folder
-	 */
+/**
+ * Parses the JavaScript template file to generate a new JavaScript file including the evaluated results
+ * @param pathToSession, path to the verification session folder
+ */
 	public static void parseJSTemp_generateJSFile(String pathToSession){
 		/** The raf. */
Index: trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/testexecution/actions/ExecuteTestsAction.java
===================================================================
--- trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/testexecution/actions/ExecuteTestsAction.java	(revision 1170)
+++ trunk/modelicaml/org.openmodelica.modelicaml.simulation/src/org/openmodelica/modelicaml/simulation/testexecution/actions/ExecuteTestsAction.java	(revision 1247)
@@ -2,5 +2,4 @@
 
 import java.io.File;
-import java.lang.reflect.InvocationTargetException;
 
 import org.eclipse.core.resources.IFile;
@@ -10,6 +9,4 @@
 import org.eclipse.core.runtime.jobs.Job;
 import org.eclipse.jface.action.IAction;
-import org.eclipse.jface.dialogs.ProgressMonitorDialog;
-import org.eclipse.jface.operation.IRunnableWithProgress;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.IStructuredSelection;
@@ -43,7 +40,10 @@
 		
 		if (this.xmlFilePath != null) {
+			System.out.println(xmlFilePath);
 			
-			//START of the execution as a job. 
-			//TODO 20110924 change to dynamic path
+			//TODO 20110924 change to dynamic path!! Final is needed for Jobs (internal class)
+			final String pathToSession = "C:/Projects/ModelicaML/runtime-New_configuration/modelicaml.example.potableWaterSystem_v30/verification-gen/verification-session_20120124110026/";
+
+			//START of the execution as a job.
 			
 			//PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell()
@@ -55,9 +55,7 @@
 						monitor.beginTask("Doing something timeconsuming here", 100);
 						{
-							String sessionFolderPath = "C:\\Projects\\ModelicaML\\runtime-New_configuration\\modelicaml.example.potableWaterSystem_v26\\test-gen\\test-session_20111021101526\\";
-							
-							TestSession testSessionObj = TestSessionXML_Reader.readFromXML(sessionFolderPath + "test_session.xml");
+							TestSession testSessionObj = TestSessionXML_Reader.readFromXML(pathToSession + "verification_session.xml");
 							String omcTempWorkingFolder = System.getenv().get("OPENMODELICAHOME") + "/tmp"; 
-							File sessionFolder = new File(sessionFolderPath);
+							File sessionFolder = new File(pathToSession);
 							String omcMessage =	ExecuteSimulation.executeAllModels(monitor, sessionFolder, omcTempWorkingFolder, testSessionObj);
 							if(omcMessage.isEmpty()){
@@ -81,5 +79,4 @@
 								}
 							}
-							ParseJavaScript.parseJSTemp_generateJSFile(sessionFolderPath);	
 						}
 						monitor.done();
@@ -90,9 +87,19 @@
 			job.schedule();
 
+			//END of the execution as a job.
+			//START of the evaluation as a job.
+			Job job2 = new Job("Simulating and Evaluating Test Results") {
+				protected IStatus run(IProgressMonitor monitor) {
 
-			
-
-			
-			//END of the execution as a job.
+						monitor.beginTask("Evaluating Simulation Results", 100);
+						{
+							ParseJavaScript.parseJSTemp_generateJSFile(pathToSession);
+						}
+						monitor.done();
+						return Status.OK_STATUS;
+					}
+			};
+			job2.setUser(true);
+			job2.schedule();
 			
 			// TODO: When finished -> run the update action 
@@ -129,63 +136,63 @@
 	
 	public static void main(String[] args) {
-		String sessionFolderPath = "C:\\Projects\\ModelicaML\\runtime-New_configuration\\modelicaml.example.potableWaterSystem_v26\\test-gen\\test-session_20111021101526";
+		String pathToSession = "C:/Projects/ModelicaML/runtime-New_configuration/modelicaml.example.potableWaterSystem_v30/verification-gen/verification-session_20120124110026/";
 		
-//		TestSession testSessionObj = TestSessionXML_Reader.readFromXML(sessionFolderPath + "test_session.xml");
-//		String omcTempWorkingFolder = System.getenv().get("OPENMODELICAHOME") + "/tmp"; 
-//		File sessionFolder = new File(sessionFolderPath);
-////		File tempSimulationFolder = new File(sessionFolderPath);// + "tmp");
-////		tempSimulationFolder.mkdir();
-////		tempSimulationFolder.canWrite();
-//		String omcMessage =	ExecuteSimulation.executeAllModels(sessionFolder, omcTempWorkingFolder, testSessionObj);
-//		if(omcMessage.isEmpty()){
-//			
-//		}
-//		else
-//			System.out.println("OMC Message: /n" + omcMessage);
-//		
-//		for(TestModel model : testSessionObj.testModels){
-//			cp.copyFile(omcTempWorkingFolder + "/" + model.qualifiedName + ".exe", sessionFolder + "/" + model.qualifiedName + ".exe");
-//			cp.copyFile(omcTempWorkingFolder + "/" + model.qualifiedName + "_init.xml", sessionFolder + "/" + model.qualifiedName + "_init.xml");
-////			cp.copyFile(omcTempWorkingFolder + "/" + model.qualifiedName + "_res.plt", tempSimulationFolder + "/" + model.qualifiedName + "_res.plt");
-//			try {
-//				SimulationResult_XML_generator.createXML(omcTempWorkingFolder + "/" + model.qualifiedName + "_res.plt", sessionFolder + "/" + model.qualifiedName + "_res.xml");
-//			} catch (Exception e) {
-//				// TODO Auto-generated catch block
-//				e.printStackTrace();
-//			}
-//		}//done
+		TestSession testSessionObj = TestSessionXML_Reader.readFromXML(pathToSession + "verification_session.xml");
+		String omcTempWorkingFolder = System.getenv().get("OPENMODELICAHOME") + "/tmp"; 
+		File sessionFolder = new File(pathToSession);
+//		File tempSimulationFolder = new File(sessionFolderPath);// + "tmp");
+//		tempSimulationFolder.mkdir();
+//		tempSimulationFolder.canWrite();
+		String omcMessage =	ExecuteSimulation.executeAllModels(null, sessionFolder, omcTempWorkingFolder, testSessionObj);
+		if(omcMessage.isEmpty()){
+			
+		}
+		else
+			System.out.println("OMC Message: /n" + omcMessage);
+		
+		for(TestModel model : testSessionObj.testModels){
+			cp.copyFile(omcTempWorkingFolder + "/" + model.qualifiedName + ".exe", sessionFolder + "/" + model.qualifiedName + ".exe");
+			cp.copyFile(omcTempWorkingFolder + "/" + model.qualifiedName + "_init.xml", sessionFolder + "/" + model.qualifiedName + "_init.xml");
+//			cp.copyFile(omcTempWorkingFolder + "/" + model.qualifiedName + "_res.plt", tempSimulationFolder + "/" + model.qualifiedName + "_res.plt");
+			try {
+				SimulationResult_XML_generator.createXML(omcTempWorkingFolder + "/" + model.qualifiedName + "_res.plt", sessionFolder + "/" + model.qualifiedName + "_res.xml");
+			} catch (Exception e) {
+				// TODO Auto-generated catch block
+				e.printStackTrace();
+			}
+		}//done
 		
 		
-		ProgressMonitorDialog dialog = new ProgressMonitorDialog(PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell());
-		try {
-			dialog.run(true, true, new IRunnableWithProgress() {
-				@Override
-				public void run(IProgressMonitor monitor) {
-					monitor
-							.beginTask("Doing something timeconsuming here",
-									100);
-					for (int i = 0; i < 10; i++) {
-						if (monitor.isCanceled())
-							return;
-						monitor.subTask("I'm doing something here " + i);
-						try {
-							Thread.sleep(1000);
-						} catch (InterruptedException e) {
-							// TODO Auto-generated catch block
-							e.printStackTrace();
-						}
-						// worked increates the monitor, the values is added to the existing ones
-						monitor.worked(1);
-					}
-					monitor.done();
-				}
-			});
-		} catch (InvocationTargetException e) {
-			e.printStackTrace();
-		} catch (InterruptedException e) {
-			e.printStackTrace();
-		}
+//		ProgressMonitorDialog dialog = new ProgressMonitorDialog(PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell());
+//		try {
+//			dialog.run(true, true, new IRunnableWithProgress() {
+//				@Override
+//				public void run(IProgressMonitor monitor) {
+//					monitor
+//							.beginTask("Doing something timeconsuming here",
+//									100);
+//					for (int i = 0; i < 10; i++) {
+//						if (monitor.isCanceled())
+//							return;
+//						monitor.subTask("I'm doing something here " + i);
+//						try {
+//							Thread.sleep(1000);
+//						} catch (InterruptedException e) {
+//							// TODO Auto-generated catch block
+//							e.printStackTrace();
+//						}
+//						// worked increates the monitor, the values is added to the existing ones
+//						monitor.worked(1);
+//					}
+//					monitor.done();
+//				}
+//			});
+//		} catch (InvocationTargetException e) {
+//			e.printStackTrace();
+//		} catch (InterruptedException e) {
+//			e.printStackTrace();
+//		}
 		
-//		ParseJavaScript.parseJSTemp_generateJSFile(sessionFolderPath);	
+		ParseJavaScript.parseJSTemp_generateJSFile(pathToSession);	
 	}
 }